#
# spec file for package yaz
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libname libyaz5
Name:           yaz
Version:        5.34.2
Release:        1.2
Summary:        Z39.50 protocol server and client
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://www.indexdata.com/resources/software/yaz/
Source:         http://ftp.indexdata.dk/pub/yaz/yaz-%{version}.tar.gz
Patch0:         yaz-icu-76.patch
BuildRequires:  gnutls-devel
BuildRequires:  libicu-devel
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  libxslt-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  tcpd-devel
BuildRequires:  pkgconfig(libxml-2.0)

%description
This package contains both a test-server and clients (normal & ssl) for
the ANSI/NISO Z39.50 protocol for Information Retrieval.  SRW and SRU
clients and servers are also supported.

%package doc
Summary:        Documentation for %{name} (Z39.50 Library)
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
YAZ is a C library for developing client and server applications
using the ANSI/NISO Z39.50 protocol for Information Retrieval.

This package contains the documentation.

%package -n %{libname}
Summary:        Z39.50 protocol library
Group:          System/Libraries
Provides:       libyaz = %{version}
Obsoletes:      libyaz < %{version}

%description -n %{libname}
YAZ is a C library for developing client and server applications
using the ANSI/NISO Z39.50 protocol for Information Retrieval.

%package -n libyaz-devel
Summary:        Headers for the Z39.50 protocol library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Requires:       libicu-devel
Requires:       libxslt-devel
Requires:       openssl-devel
Requires:       tcpd-devel

%description -n libyaz-devel
YAZ is a C library for developing client and server applications
using the ANSI/NISO Z39.50 protocol for Information Retrieval.

%prep
%autosetup -p1

%build
autoreconf -fiv
#  --with-dsssl=/usr/share/sgml/docbook/dsssl-stylesheets \
#  --with-dtd=/usr/share/sgml/db41xml
%configure --enable-shared \
		   --enable-tcpd \
		   --with-xslt \
           --with-openssl \
           --with-gnutls \
           --with-icu \
		   --disable-static
%make_build

%install
%make_install
# Unwanted doc stuff
rm -fr %{buildroot}%{_datadir}/doc
rm -fr html
mkdir html
cp -a doc/*.html html
chmod 644 html/*.html
# cp doc/*pdf .
ln -sf introduction.html html/index.html
# yaz.pdf
%define DOCFILES README.md LICENSE NEWS
{
  echo "<html><head><title>%{name} documentation directory</title></head>"
  echo "<body><ul>"
  echo "<li><a href=\"html/index.html\">%{name}</a>, official documentation (local)"
  for f in %{DOCFILES} http://www.indexdata.dk/links/  ; do
    if [ "http:" = "${f%%%%/*}" ]; then
      echo "<li><a href=\"$f\">$f</a>"
      continue
    fi
    [ -f $f ] || continue
    echo "<li><a href=\"$f\">$f</a>"
  done
  echo "</li></body></html>"
} >index.html
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc %{DOCFILES} ChangeLog
%{_bindir}/yaz-client*
%{_bindir}/yaz-iconv
%{_bindir}/yaz-icu
%{_bindir}/yaz-illclient
%{_bindir}/yaz-marcdump
%{_bindir}/yaz-url
%{_bindir}/yaz-ztest*
%{_bindir}/zoomsh
%{_bindir}/yaz-json-parse
%{_bindir}/yaz-record-conv
%{_mandir}/*/yaz.*
%{_mandir}/*/yaz-illclient.*
%{_mandir}/*/yaz-client.*
%{_mandir}/*/zoomsh.*
%{_mandir}/*/yaz-iconv.*
%{_mandir}/*/yaz-icu.*
%{_mandir}/*/yaz-log.*
%{_mandir}/*/yaz-url.*
%{_mandir}/*/yaz-ztest.*
%{_mandir}/*/yaz-marcdump.*
%{_mandir}/*/yaz-json-parse.*
%{_mandir}/*/yaz-record-conv.*
%{_mandir}/*/bib1-attr.*
%dir %{_datadir}/yaz
%{_datadir}/yaz%{_sysconfdir}

%files doc
%doc index.html html

%files -n %{libname}
%{_libdir}/*.so.*

%files -n libyaz-devel
%{_bindir}/yaz-config
%{_bindir}/yaz-asncomp
%{_includedir}/yaz
%{_libdir}/*.so
%{_datadir}/yaz/z39.50
%{_datadir}/yaz/ill
%{_datadir}/aclocal/yaz.m4
%{_mandir}/man1/yaz-config.*
%{_mandir}/man1/yaz-asncomp.*
%{_libdir}/pkgconfig/yaz.pc
%{_libdir}/pkgconfig/yaz-icu.pc
%{_libdir}/pkgconfig/yaz-server.pc

%changelog
* Fri Nov 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 5.34.2:
  + Remove outdated distros: Debian Stretch and Ubuntu Trusty
  + LICENSE: Update to match Index Data's online Revised BSD license
  + Vscode XML editor settings
  + YAZ 5.34.1 breaks search with OCLC's "Sisis InfoGuide" origin
- Add yaz-icu-76.patch: Fix build against ICU 76: most sources
  found in the wild wrongly define the need on icu-i18n, when most
  actually would need icu-uc.
- Add libtool BuildRequires and call autoreconf in build section,
  as above patch touches the build system.
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 5.34.1:
  * Build: fix implicit atoi/stdlib includes (libxml >2.12) #104
  * Build: fix libxml2 2.13 reorganizing headers #102
  * Build: fix always true pointer checks #108
  * Build: update m4 to fix cross-builds
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 5.34.0:
  * Fixes to Solr response decoding.
  * Fix compilation with Visual Studio Failed for YAZ 5.33.0.
  * JSON pretty-printed same way as jq for yaz-json-parse and yaz-marcdump
  * utilities.
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 5.33.0:
  * yaz-marcdump: SAX based MARCXML parsing. This is about 3 times faster
  * than before.
  * yaz-marcdump: new option -r prints summary of number of records
    processed.
  * Document ZOOM option 'rpnCharset'.
  * Fix cross-compiling with pkg-config.
* Mon Aug  8 2022 Dirk Müller <dmueller@suse.com>
- update to 5.32.0:
  * backtrace: allow gdb to operate on this process.
  * backtrace: hard exit if backtrace hangs.
  * yaz-marcdump: limit, offset options. Limit(-L), offset(-O) allows records
    in range to be processed.
* Mon Jan 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: no apparent reason detected why we need
  - 32bit libaries and devel packages. The previously existing
  package already was not installable, so defacto no loss.
* Fri Jan 21 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 5.31.1
  * Fixed #61: yaz-url redirect segfault in case of redirect host failure.
  * Update yaz_encode_uri_component for RFC3986. Previous implementation
    based on RFC2396.
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
* Thu May  6 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.31.0
  * Fixed yaz-marcdump: json input and leader at end undefined behavior.
  * Enable xi:include processing for yaz_xml_include_glob and
    yaz_xml_include_simple
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.30.3:
  * Require getaddrinfo which has been available since 2003.
  * Provide server host for SSL by using gnutls_server_name_set(3).
  * Obey [host]:port notation for IPV6
* Wed May  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.30.2:
  * Extend the record conversion routines to handle OPAC encoding
    with outputcharset and leaderspec.
  * Fix #54 in cql_strerror: incorrect call to yaz_diag_to_str YAZ-928.
  * Partly revert UTF-8 records returned by yaz-ztest (introduced in 5.30.0)
  * Fixes pazpar2 tests that relies on specific records being returned.
  * Increase a few buffers due to compiler warning
  * Buffers are involving %%d-conversions.
* Sat Mar 14 2020 lars@linux-schulserver.de
- Update to 5.29.0:
  + Several fixes for danmarc(2) charset encoding and decoding.
    YAZ-923 YAZ-924
  + Fix yaz-marcdump silently creates MARC-records with an
    invalid director YAZ-926
  + Add pkg-config templates for YAZ ICU and YAZ server YAZ-925
  5.28.0 2019/11/28
  + Element-set is case sensitive for yaz_retrieval. The element-set
  name should be case insensitive, and thus, the name property
  is matched in a case-insensive mannner. YAZ-922
  5.27.2 2019/10/07
  + Fix hitting directory for docpath results in malloc failure YAZ-921
  + Fix attempt to write HTTP to a non-listening socket loops YAZ-919
  + Fix yaz-ztest SSL does not work when forking YAZ-918
  5.27.1 2018/12/03
  + Use pkg-config to detect ICU . Closes #41
  + Describe ZOOM option timeout
  + Fix typos in yaz-client man page and other typos
  5.27.0 2018/10/08
  + GFS: Allow External type TaskPackage response YAZ-915
  + zoomsh: fset command YAZ-916
  + Improve logging of extended service task type YAZ-914
  + yaz-client: document the third arg to the show command #37
  5.26.1 2018/07/11
  + Fix segv with element-set=null and split YAZ-913
  5.26.0 2018/07/09
  + Allow suffix split for retrieval element-set names YAZ-912
  + cql2ccl: case sensitive comparisons for ops etc YAZ-911
  5.25.0 2018/05/04
  + ZOOM C: return extended services diagnostics separately YAZ-908
  The diagnostic code and additional info is saved in options
  esError and esAddinfo respectively - as part of the ZOOM package.
  5.24.0 2018/04/25
  + New option for ZOOM C' record update: recordIdString (the string
  variant of recordId). Until now only recordIdNumber and recordIdOpaque
  was possible. YAZ-907
  + Update for Visual Studio 2017. Bundle runtime from that compiler. YAZ-905
  + yaz FTCBFS: uses the build architecture pkg-config YAZ-897
  5.23.1 2017/09/04
  + Fix Omitted Content-Length not handled anymore YAZ-894
  This issue was introduced by work in YAZ-878 YAZ Version 5.20.0.
  5.23.0 2017/08/04
  + Allow for more Solr URL schemas YAZ-893
  If the Solr URL contains ? it will be treated as a URL that
  includes request handler rather than hard-coded /select. For example
  /solr/search? . You can also pass own arguments. For example
  /solr/search?foo=bar .
- removed upstreamed patches:
  + yaz-5.22.0-codecleanup.patch (yaz-5.1.2-codecleanup.diff)
  + yaz-5.22.0-client.patch
* Mon Jul  3 2017 lars@linux-schulserver.de
- Update to 5.22.0
  + rdf-lookup: Add timeout configuration option YAZ-891
    Add yaz_url_set_timeout
  + rdf-lookup: report error if X-Path cannot be compiled YAZ-890
  + rdf-lookup: avoid double dash in generated XML comments
  + rdf-lookup: fix misleading log on rdf-failures YAZ-884
  + Add documentation for <param> tag in xslt retrieval facility doc
  + comstack: Fix compilation error if getaddrinfo does not exist
  + yaz-url: ignore content-length for HTTP method HEAD YAZ-878
  + retrieval: fix incorrect backend schema YAZ-877
  + record_conv: allow HTTP method to be set for authority lookup
  + record_conv: change error for unsupported backend element
  + New type, rdf-lookup, for record conversion system (retrieval)
  + Fix yaz_url_exec sending same uri for 2nd call
  + cql2pqf: relation modifiers with name and value are converted
    to proximity with unit=element. Left operand is the the primary
    index and term. Right operand is attribute index-name mapping of name
    and value being the relation modifier value. For example,
    dc.title =/dc.language=dk kirke
    could be mapped to
    @prox 0 0 0 0 k 8 @attr 1=4 "kirke" @attr 1=54 dk
  + Add ProximityUnit map to/from string utility
  + New functions z_ProxUnit_to_str and z_str_to_ProxUnit.
  + Allow multi-byte indicators for MARC subsystem
  + JSON: to the spec check of number
  + JSON: strict \uxxxx sequence
  + JSON: fail for nesting more than 1000 levels
  + JSON: distinguish between EOF and error
  + CCL: fix r=o, r=r WRT inherited attributes YAZ-864
  + ZOOM C: tweak when connection failed is returned
  + ZOOM C: deal with excess bytes HTTPS case YAZ-833
  + Fix ZOOM: crash extended services diagnostics YAZ-846
  + Make yaz_log_reopen async-signal YAZ-845
  + Add lock/unlock for YAZ log writes YAZ-843
  + Fix yaz-client command args parsing broken YAZ-855
  + yaz-client: deal with excess bytes HTTPS case YAZ-833
  + Allow Content-Type application/sru+xml YAZ-840
  + New yaz_xml_get_prop utility YAZ-839
  + Extend get_org_info (snippets) to return original string YAZ-836
  + Deal with excess bytes in HTTP response for keepalive YAZ-830
  + Refactor ssl_put and tcpip_put to one function YAZ-832
  + Refactor ssl_get and tcpip_get to one function YAZ-831
  + Fix SEGV yaz-client for HTTP decoding error YAZ-829
  + Fix buffer overflow in cmd_elements in yaz-client YAZ-828
  + Use CONNECT for SSL backends and for Z39.50 thru HTTP proxy YAZ-825
  + Fix http proxy fails with yaz-client YAZ-824
  + Fix 0 ptr reference for OPAC records from XML YAZ-822
  + Extend yaz daemon facility to assist int log rotation YAZ-818 YAZ-819
  + Moved YAZ and many other software components to GitHub
- yaz-record-conv now installed and packaged
- Adjust and rename code cleanup patches (yaz-4.1.7-codecleanup.diff
  and yaz-4.1.7-client.diff)
- removed yaz-4.2.47-implicit_definitions.patch: somehow fixed
  upstream (no compiler warnings any more)
* Thu Jan 15 2015 lars@linux-schulserver.de
- Update to 5.8.1:
  + record conv: 'select' return org record if no x-path match YAZ-814
  + retrieval: pick matched element-set rule YAZ-813
  + Fix crash in record conv rule 'select' YAZ-812
  + record_conv: selection by X-Path YAZ-811
    That's a new step in record conversion system (<select path=".."/>)
  + Document record render parameters for ZOOM - including base64
  + Fix application/x-www-form-urlencoded + empty YAZ-810
    A SEGV occurred if Content-Type was "application/x-www-form-urlencoded"
    and empty content was supplied.
  + Fix yaz-iconv man page for typos and incorrect example. YAZ-809
  + Fail hard if Bison is not found and is needed YAZ-808
  + Enable YAZ backtrace for programs YAZ-802
  + Fix daemon: parent process stops before child YAZ-806
    Try to fix the situation where parent process stops before
    child has acknowledged it .. SIGUSR2 back!
  + daemon: log message when keepalive stops.
- rename libpackage to libyaz5 to follow library naming
- small specfile cleanup
* Tue Dec  9 2014 ke@suse.de
- Update to 5.7.1:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS.
* Tue Jun  3 2014 ke@suse.de
- Update to 5.1.2:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS.
- yaz-5.1.2-codecleanup.diff: Adjust yaz-4.1.7-codecleanup.diff for
  this version (5.1.2).
* Thu Aug 29 2013 ke@suse.de
- Update to 4.2.65:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS; e.g. since the last update:
  + New utility z_get_HTTP_Response_details - an extended version of
    z_get_HTTP_Response.
  + New utility yaz_url_get_error which returns error message of last
    failed yaz_url_exec call.
  + yaz-url and url functions: allow max HTTP redirects to be
    controlled.
  + New functions yaz_file_glob2, yaz_xml_include_glob.
* Thu Jun  6 2013 ke@suse.de
- Update to 4.2.57:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS; e.g.:
  + Conversion between Z39.50 OPAC and OPACXML.
* Mon Jan 28 2013 lars@linux-schulserver.de
- update to 4.2.49:
  + ICU has a new conversion element 'join', which joins tokens
    into one with a custom character given by the rule attribute.
  + New GFS search member: present_number. This is a hint to the
    search handler how many records are going to be fetched immediately
    following search. There's no guarantee that it's going to be
    the case, since it depends on hit count (for Z39.50 piggyback)
    and whether errors turn up.
  + Make a few functions static (private). The functions getbyte_stream,
    ungetbyte_stream and yaz_gets are now private. They were never
    declared in a header file.
  + ZOOM: special options to control APDU logging.
    Using ZOOM_connection_option_set(c, "saveAPDU", "1") will enable
    logging of APDUs until "saveAPDU" option is set again. If logging is
    already enabled the effect is that current APDU buffer is cleared.
    Using ZOOM_connection_option_set(c, "saveAPDU", "0") disables
    logging (default behavior on new connection).
    The APDUs sent/received can be obtained by using
    Using ZOOM_connection_option_get(c, "APDU") or
    ZOOM_connection_option_getl(c, "APDU", &l).
  + GFS: relay implementation_version from backend
    From 3.0.40 and later, implementation_version from backend was
    not used in init response at all.
- added yaz-4.2.47-implicit_definitions.patch
- small specfile cleanup
* Mon Oct 22 2012 ke@suse.de
- Update to 4.2.43:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS.
- Create doc subpackage with HTML files.
* Mon Sep 17 2012 ke@suse.de
- Update to 4.2.38:
  + Various enhancements and bug fixes; for more info, see
    http://www.indexdata.com/yaz/doc/NEWS.
* Thu Jun 21 2012 ke@suse.de
- Update to 4.2.34:
  + Bug fixes.
* Thu Jun 21 2012 ke@suse.de
- Update to 4.2.33:
  + New SRU diagnostics.
  + Documentation enhancements.
  + record_conf improvements.
  + For detailed info, see
    http://www.indexdata.com/yaz/doc/NEWS
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs.conf for package
- Remove redundant sections
* Sat Sep 10 2011 lars@linux-schulserver.de
- update to 4.2.14:
  + New ZOOM utility ZOOM_query_sortby2
  + New functions yaz_sort_spec_to_{cql,type7}
  + rpn2solr supports Z39.58 truncation (104)
  + yaz-client: allow scanpos of "none"
  + cql2pqf: refactor truncation handling and fix Z39.58 mode
  + CQL/CCL/PQF conversion fixes. CCL support for Z39.58 trunc
  + cql2ccl: term code for all/any sequences as well
  + cql2ccl: fix handling of \\
  + for more Information, see
    /usr/share/doc/packages/yaz/ChangeLog
- rename libyaz to libyaz4 to follow shared library packaging
  standard - and move problematic files to the yaz main package
* Tue Aug  2 2011 idonmez@novell.com
- Cleanup the spec file
- Add BuildRequires on pkg-config because the package installs a
  pkgconfig file.
- Enable strict-aliasing again since the code seems to be fixed.
* Wed May 25 2011 ke@suse.de
- Update to 4.2.0:
  * CQL improvements and enhancements.
  * For detailed changes, see http://indexdata.com/yaz/doc/NEWS.
* Wed Apr  6 2011 ke@suse.de
- Update to 4.1.7:
  * Add -lCrun when linking with ICU on Solaris.
  * More quicks character set conversions for OPAC records.
  * For earlier changes, see http://indexdata.com/yaz/doc/NEWS.
- Adjust or rename code cleanup patches (yaz-4.1.7-codecleanup.diff and
  yaz-4.1.7-client.diff).
* Wed Aug 25 2010 ke@suse.de
- Update to 4.0.12; for details see http://indexdata.com/yaz/doc/NEWS.
- Remove obsolete yaz-codecleanup.44.diff.
- Rebuild remaining diffs.
* Tue Nov 17 2009 ke@suse.de
- Update to 3.0.50; for details see
  http://www.indexdata.com/yaz/doc/NEWS.
* Thu Mar  5 2009 ke@suse.de
- Update to 3.0.44; for details see http://indexdata.dk/yaz/NEWS.
- Adjust patch files for this version.
* Tue Jan 13 2009 crrodriguez@suse.de
- remove 5MB of useless static libraries
* Thu Jul  3 2008 ke@suse.de
- Version 3.0.34 (extract from the NEWS file since 3.0.16):
  * License issues:
  * * yaz-ziffy is no longer part of YAZ. It is distributed separately by
  Index Data because ziffy's license is GPL2 rather then 'Revised BSD'.
  * * Changed license of CCL module to 'Revised BSD'. After consultation with
  remaining members of the original EUROPAGATE consortium, we are re-issuing
  the CCL module without a separate license. The software was developed by
  Index Data as part of a research project. The special license was included
  to help feed usage information back to the project consortium to support
  project evaluation. At this time, the project consortium has long-since
  disbanded, and the majority of the original principals have retired. At the
  same time, we have significantly modified the software during the following
  years, to the point where very practically no original code remains. To
  simplify re-use of the software, we have contacted those members of the
  consortium who could be reached, and agreed to re-issue the module as a
  proper part of the YAZ package.
  * New features:
  * * Implement SSL sockets using GNU TLS (not enabled).
  * * yaz-ztest returns OPAC records if a client asks for OPAC.
  * * Improve speed of MARC-8 encoding.
  * * Add support for lossy and loss-less MARC-8 encoding.
  * * yaz-client's itemorder command may now send a file.
  * * Fixed yaz-marcdump to allow the use of NS prefix for record element.
  * * Add OPAC XML XSD (etc/opacxml.xsd).
  * * CQL closer to being version 1.2 compliant.
  * * Tcl scripts uses /usr/bin/tclsh as preferred shell.
  * Bug fixes:
  * * Handle G1 sequneces in MARC-8 decoding. Bug #2115.
  * * Bug #395: ZOOM_record / OPAC record encoding problems.
  * * Fix error handling in cs_listen. Bug #2037.
- Enable ICU support.
- Cleanup spec file.
* Tue Nov 20 2007 ke@suse.de
- Version 3.0.16 (extract from the NEWS file since 3.0.6):
  * Add yaz_poll. This allows more than 1024 sockets to be in use.
  * Add ICU wrapper library which exposes ICU http://www.icu-project.org/
  functionality.
  * Add HTTP tunnel facility for COMSTACK, bug #1752.
  * Add support for SRU scan for ZOOM.
  * Add support for HTTP Basic authentication in clients.
  * More MARC-8/UTF-8 conversion fixes and other bug fixes.
- Package ziffy on all architectures.
* Thu Oct  4 2007 bg@suse.de
- package ziffy also for hppa
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Mon Jun 11 2007 ke@suse.de
- Version 3.0.6 (from the NEWS file since 3.0.2):
  * Fixed bug in character set conversion of BER strings. Bug introduced
    in 3.0.0.
  * yaz-client does not read .yazclientrc from current
    directory. yaz-client now reads commands from file given by option
  - f if specified; then tries to read .yazclientrc in current
    directory.  Failing that, it reads .yazclientrc from user's home
    directory.
  * Extensions.
- Start with spec file fixes and cleanup: move ldconfig calls to the
  libyaz package, remove explicit libxml2 requirement, etc.
* Thu May 10 2007 ke@suse.de
- Version 3.0.2, which is binary incompatible (from the NEWS file since
  3.0.0 resp. 2.1.48):
  * Split YAZ library into libyaz and libyaz_server.
  * CCL and other enhancements: partial support for ISO5428-1984
    (Greek).
  * Bug fixes.
- Adjust yaz-codecleanup.36.diff for version 3.0.2 (see
  yaz-3.0.2-client.diff).
- Add -fno-strict-aliasing because of query-charset.c: 47
* Thu Jan 25 2007 lrupp@suse.de
- updated to 2.1.48
- enabled with-xslt (add: libxml2-devel to BuildRequires)
- build parallel
- add libxml2 to requires for libyaz
- package ziffy only on %%ix86 ia64 s390 ppc (needs more improvement)
* Wed Jan 10 2007 ke@suse.de
- Version 2.1.44 (from the NEWS file since 2.1.36):
  * Bug fixes.
  * Rename yaz-marcdump options.
  * Add ziffy, the promiscuous Z39.50 APDU sniffer (GPL v2).
  * Updates for SRU Update,
* Wed Oct 25 2006 ke@suse.de
- Version 2.1.36 (from the NEWS file since 2.1.32):
  * Implemented yaz_filepath_comp which splits a path into file path
    components (required by Zebra 2.0.3+).
  * Bugfixes: Missing log lines; CQL to PQF translation: preserve
    double-quote escaping; add SRU diagnostics; fix printf specifiers [#
    214434, reported by David Binderman]; change type of optval from
    long to int for invocation of setsockopt with the SO_REUSEADDR option.
  * New ZOOM function, ZOOM_connection_is_idle, which checks
    whether a connection is idle.
  * Add support for specifying the max log file size for the Generic
    Frontend Server. The size is given with option -r.
- Update yaz-codecleanup.diff as yaz-codecleanup.36.diff
* Wed Oct 18 2006 pth@suse.de
- Cleaned up the code a bit.
- Fix an off-by-one error (#207880).
* Thu Sep 21 2006 ke@suse.de
- Version 2.1.32 (from the NEWS file):
  * Fix problem WRT unix sockets in the ZOOM code.
* Tue Sep 19 2006 ke@suse.de
- Version 2.1.30 (for more information see the NEWS file):
  * Fix bug in Generic Frontend Server that could cause a server to stop
    accepting new connections.
  * For the generic frontend server, the maximum record size is used as
    maximum size of incoming packages (SRU + Z39.50).
  * TCP/IP comstack uses getaddrinfo now to resolve names. It should be
    IPV6 friendly now.
  * Fix bug: Using Non Reentrant gethostbyname causes SIGSEGV.
  * New option for yaz-marcdump -lpos=value which allows setting a portion
    of MARC header to a certain value.
  * Fixes for MARC generation when encoded as MARC-8.
  * ZOOM-C reads option extraArgs. If set the value of extraArgs is
    appended to SRU URI (POST/GET). Value must be URL encoded, such as
    x-id-a=v1&x-id-b=v2 .
* Thu Aug 17 2006 ke@suse.de
- Version 2.1.26: Two bug fixes.
* Mon Aug 14 2006 ke@suse.de
- yaz-devel: Requires libxslt-devel.
* Thu Aug 10 2006 ke@suse.de
- Update to 2.1.24 (from NEWS since 2.1.18):
  * Fixed MARC ISO2709 encoding routines
  * Change cql2pqf transformation to use a different evaluation order.
  * For Libxml2 and friends, YAZ defines YAZ_HAVE_{XML2,XSLT,EXSLT) in the
    compilation phase, but also for yaz-config --cflags output.
  * Change SRU update structure bend_update_rr so that SRU diagnostics are
    stored in uri, message and details.
  * Add support for CCL, compiled on the client side, in ZOOM-C.
  * Enhancements for yaz-client (sru).
  * Documentation for YAZ is now based on the Docbook XML/XSLT using
    xsltproc + N Walsh's stylesheets.
  * Add retrieval handling support in Generic Frontend Server to support
    conversion between MARC/XML as well as XSLTtransforms. See
    etc/yazgfs.xml for an example.
  * Add authentication support to Generic Frontend Server in SRU mode.
  * Add support for a new character set MARC8s identical to MARC8 except
    that it converts combined characters to single Unicode characters in the
    Latin-1 range (when possible).
  * And more bug fixes and new features.
* Thu Jun  1 2006 ke@suse.de
- Update to version 2.1.18 (from NEWS):
  * Improve MARC, ZOOM, and CQL; MARC-8 support.
  * Better localization.
  * Add ZiNG Update Support.
  * Various Bug fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jun  8 2005 ke@suse.de
- Update to version 2.1.8.
* Fri May 27 2005 ke@suse.de
- Update to version 2.1.6 (from NEWS):
  * Add support for SRW sort in Generic Frontend Server.
  * Bugfixes (for more info see NEWS).
* Thu Apr 28 2005 ke@suse.de
- Update to version 2.1.4 (from NEWS):
  * Change include/yaz/diagbib1.h and added include/yaz/diagsrw.h with
    diagnostic messages+codes for Bib-1 and SRW.
  * Modify the yaz-marcdump utility to skip garbage bytes between MARC
    records in a file.  Also skip garbage bytes between ISO2709 records
    rather than abort.
  * Program yaz-client now exits and produces an error message if multiple
    Z39.50 servers are specified on the command line.
- Remove expat from neededforbuild.
* Tue Apr  5 2005 ke@suse.de
- Update to version 2.1.2 (from NEWS):
  * Add support for virtual hosts and multiple backend servers for
    the YAZ frontend server. The configution is XML based and
    support specificition of CQL to RPN mappings and explain
    information.  See section "Virtual Hosts" in the YAZ manual.
  * Extended OPAC display utility. OPAC display utility renders
    bibliographic (MARC) record as well.
* Thu Feb 10 2005 ke@suse.de
- Update to version 2.0.34:
  * Fix bugs in the MARC-8 to UTF-8 conversion.
  * Add support for the proposed MarcXchange format.
* Wed Jan 12 2005 ke@suse.de
- Update to version 2.0.32:
  * Add support for SRW scan in yaz-client and Generic Frontend Server.
* Tue Jan  4 2005 ke@suse.de
- Update to version 2.0.30:
  * Bug fixes.
  * Change logging behavior.
* Tue Nov 16 2004 ke@suse.de
- Update to version 2.0.28; changes since 2.0.26:
  * Various bug fixes.
  * Improve documentation.
- Add tcpd and tcpd-devel to neededforbuild.
* Fri Oct  8 2004 ke@suse.de
- Update to version 2.0.26; changes since 2.0.22:
  * Various bug fixes.
  * Add YAZ GFS support for conversion from Z39.50 surrogate diagnostics
    to SRW surrogate diagnostics.
  * Fixes for MARC-8 in yaz_iconv character set utilies. The MARC-8
    to UTF-8/UCS conversion is now only based on codetables.xml.
* Mon Aug  9 2004 ke@suse.de
- Update to version 2.0.22; changes:
  * Add support for more "commit changes" in ZOOM (uses Extended
    Services).
  * For yaz-client, command set_marcdump <file> / -m <file> dumps
    SUTRS/XML/.. records as well.
* Fri May 28 2004 ke@suse.de
- Update to version 2.0.21; changes:
  * SSL comstack now uses yaz.pem certificate file on server side
    by default. Certificate filename can be configured by calling
    comstack function cs_set_ssl_certificate_file before cs_bind is used.
  * Fix bug regarding multiple calls to ZOOM_connection_connect.
  * Implement cs_set_ssl_ctx which sets SSL_CTX for SSL comstack.
  * Do not create SSL_CTX in cs_create (ssl_type). Create in tcpip_bind,
    tcpip_rcvconnect instead. This allows user to set custom SSL_CTX.
  * ZOOM now allows inspection of X509 peer certificate for verification.
    The X509 buffer is retrived by reading ZOOM option "sslPeerCert".
  * Remove libyazssl.la. When SSL is enabled, libyaz.la has SSL support and
    all programs have too (yaz-ztest, yaz-client, zoom..).
  * Documentation about MARC decoding tools.
  * Fix encoding of xsd:string to use text instead of CDATA.
  * Fix endless loop in CQL parser with unbalanced ".
  * Use a more compact way to store MARC-8 conversion tables.
  * Fix a bug in yaz_iconv regarding conversion to UCS4 / UCS4LE.
  * Update CQL parser to use new CQL 1.1 modifiers for booleans and
    relations.
  * Another fix for decoding of XML packed records.
  * Fixes for Chunked encoding. White space not ignored after length spec.
  * Implement chunked HTTP transfer.
* Wed May 12 2004 ro@suse.de
- added -fno-strict-aliasing
* Tue Feb 17 2004 ke@suse.de
- Update to version 2.0.12; changes:
  * Various enhancements to yaz-client.
  * Fix various bugs (encoding related, memory leak, etc.).
  * Fix compilation for SSL which wasn't properly enabled for all
    platforms.
  * MARC conversion can now generate ISO2709 output in another
    character set.
  * ZOOM-C enhancements.
  * New utilities: yaz-iconv and yaz-marcdump.
  * Enhancements to the generic front-end server.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Thu Oct 16 2003 ke@suse.de
- Update to version 2.0.4; changes:
  - Allow any CQL relation (not just all,any,exact,scr).
  - Fixes for OCLC UI ASN.1 to make it work with SilverPlatter targets
    that features the same UI.
  - Implement command update0 in YAZ client which is equivalent to
    update but uses old of Ext Update ASN.1.
  - Use OID 1.2.840.10003.15.1000.81.1 for privately defined charsets
    in charset negotiation. Added VAL_ID_CHARSET in oid.h.
    Previously no OID was used for this info.
  - ZOOM uses smallSetUpperBound=1 instead of 0 for piggyback searches.
    It apparantely upsets EBSCO Publishing IR Z39.50 Server which
    returns 'malformed search term' otherwise.
  - SortResponse member resultCount now set to NULL in sort handler of
    frontend server.
  - OPAC support ZOOM. ZOOM_record_get returns OPAC info (as XML) if
    type is "opac".
  - Add three new utility functions for translating OIDs between various
    formats -- symbolic name such as "Usmarc", minus-1-terminated int
    arrays and dotted strings such as "1.2.840.10003.9.5.1".
  - Revert modifications for ES Update definition for z_IU0Update
    (OID 1.2.840.10003.9.5.1 and 1.2.840.10003.9.5). The definition
    is back to YAZ 2.0.2.
  - String value attributes for CCL parser.
  - Support for OCLC's locally registered "OCLC-UserInformation" PDU,
    which their FirstSearch server returns in Init responses, sometimes
    carrying useful diagnostic information when Init fails.  This has the
    OID 1.2.840.10003.10.1000.17.1 and is defined in the file
    "z39.50/oclcui.asn", where its definition is somewhat different from
    what OCLC document on their web-site, as required to interoperate with
    their servers.
  - Support for anonymous authentication in yaz-client.  Use the command
    "auth -".
  - Fix the OID of the Index Data-local "admin" Extended Service from
    1.2.840.10003.9.81.1 to 1.2.840.10003.9.1000.81.1.  The omission of
    the 1000, which indicates a locally-defined OID, was a mistake.
* Mon Jun 23 2003 ke@suse.de
- Update to version 2.0.3; changes:
  - Fix CCL directive @case handling so that it affects string match for
    both CCL keywords and qualifiers.
  - * ESFormat-Update updates. Packages with OID 1.2.840.10003.9.5.1 and
    1.2.840.10003.9.5 are now handled by the same decoder z_IU0Update .
    Decoder has been updated with ASN.1 changes as listed in
    http://lcweb.loc.gov/z3950/agency/defns/updateES.html
  - ZOOM_record_get may now return a record in a specific character set.
    For type use "form; charset=from[,to]" where form (render, xml, ..),
    "from" is the character set of record as returned by target. "to" is
    the character set to be returned. If omitted, "to" is UTF-8.
  - YAZ ASN.1 compiler renamed from yaz-comp to yaz-asncomp
  - New ODR utility, odr_getelement, which returns name of element for
    which encoding/decoding failed.
  - Fixed ODR so that it returns error code OREQUIRED rather than ONONE
    in cases where a required element was omitted.
  - Bug fix: some MARC8 sequences were not converted.
  - New ZOOM option "step" which specifies number of records to be
    retrieved in one chunk. Used in conjunction with "start" and "count".
  - SRW support for yaz-client. Use scheme http: to use it, e.g.
    http://host:port/db
  - yaz-client no longer does (un)intelligent character set conversions
    by default. Can be enabled with charset and marc_charset commands.
  - New function, cql_strerror() translates SRW error codes, as returned
    by cql_transform_error(), into human-readable English strings.  Used
    in yaz-client diagnostics when appropriate.
  - New CQL2RPN query-type for the command-line yaz-client, parses CQL and
    converts it into a type-1 query which is sent to the server.  This
    makes CQL available for use with all Z-servers, as opposed to the tiny
    minority that can handle CQL queries themselves.
* Thu Jun 12 2003 kukuk@suse.de
- Add missing directory to filelist
* Mon May 26 2003 ke@suse.de
- Remove unwanted files from $RPM_BUILD_ROOT.
* Thu May 22 2003 ke@suse.de
- Split subpackage libyaz into libyaz and libyaz-devel.
* Thu May 22 2003 ke@suse.de
- Update to version 2.0.2; changes:
  - New ZOOM events ZOOM_EVENT_RECV_{RECORD,SEARCH} for receiving a record
    and search result respectively.
  - New member 'schema' in struct bend_fetch_rr which the name of requested
    schema (SRW/SRU) for record (or NULL if none was given). The fetch
    handler MAY set this to reflect the schema of the returned record.
  - New member 'display_term' in struct scan_entry. GFS now sets member entries
    and allocates scan entries to be filled by user scan handler. In previous
    version, entries member was allocated by the scan handler. That still
    works,  but the GFS will ignore member display_term - assuming it was NOT
    set by the handler. The fact that the GFS now allocates the entries both
    allows for new members and makes a scan handler easier to write.
  - SRW/SRU recordPacking. For SRW default recordPacking is string. For
    SRU default recordPacking is string.
  - SRU protocol support for frontend server.
  - Add missing PQF transform rules for <= and >= .
  - Added scan for the ZOOM shell (zoomsh).
  - Bugfix: CQL lex buffer overflow.
  - Split package into yaz and libyaz.
* Wed Mar 26 2003 ke@suse.de
- Update to version 2.0; changes:
  Possible compatibility problems with earlier versions marked with '*'.
  - * String Identifers for Schemas (Amendment 5).
    http://lcweb.loc.gov/z3950/agency/amend/am5.html
  - * resultCount parameter to Sort Response (Amendment 1).
    http://lcweb.loc.gov/z3950/agency/amend/am1.html
  - Support for SRW 1.0 over HTTP. This is an optional feature and
    requires libxml2 to operate. Enable SOAP by specifying --with-xml2
    for configure (not enabled on SuSE Linux).
  - Generic frontend server supports HTTP/SOAP/SRW and Z39.50/BER
    on the same port.  SRW SearchRetrieveRequests are mapped
    to bend_init,bend_search,bend_fetch,bend_close.
  - Add Z39.50 Query Type-104 - to facilitate CQL within Z39.50.
  - CQL support. Source is directory 'cql'. CQL is supported in ZOOM
    (both SRW and Z39.50) and the YAZ client (Z39.50 only).
  - ZOOM connections are SRW based if schem http is used for hostname
    in connect, e.g.  z = ZOOM_connection_new("http://myserver");
    ZOOM_query may be of type CQL, e.g. ZOOM_query_cql(q, "dc.title=x");
  - CCL proximity operators !n, %%n converts to PQF @prox 0 n 1 2 k 2
    and @prox 0 n 0 1 k 2 respectively, meaning: exlusion=false,
    distance=n, order=true/false, relation=le, prox unit=word. If
    n is omitted, distance 1 is used.
  - New MARC decode API. All new functions operate on a yaz_marc_t
    handle. The most important new functions are: yaz_marc_create,
    yaz_marc_decode_{buf,wrbuf}, yaz_marc_destroy, .. to create handler,
    decode and destroy respectively. Decoder can produce formats
    MARC line, simple XML, OAI MARC and MARC XML (LoC). See
    include/yaz/marcdisp.h.
  - YAZ Iconv utility now supports MARC8 decoding (marc8.c). Converts
    to UTF-8, UCS-32, wchar_t or Latin-1.
  - * Prototypes for yaz_iconv_-functions moved to separate header
    include/yaz/yaz-iconv.h.
  - Make a few private functions 'static' in unix.c. This prevents
    duplicate unix_close in PHP with YAZ and imap. PHP Bug 20977.
  - For ZOOM connection, the options targetImplementation{Id,Name,Version}
    are set when Init Response is received.
  - New function ZOOM_connection_error_x similar to ZOOM_connection_error
    but returns diagnostic set as well.
  - New function yaz_strerror which is a portable wrapper for
    strerror/strerror_r/GetLastMessage.
  - * ZOOM_record_get supports type "xml" in which case MARC XML (from LOC)
    is returned for MARC. If type is "oai", then OAI MARC is returned.
* Fri Nov 29 2002 ke@suse.de
- Update to version 1.9.2; changes:
  * yaz_marc_decode uses OAI MARC as XML format for ISO2709 records.
  * Fix bad race conditions on SIGTERM and terminate gracefully in
    frontend server.
  * Move retrieval (data1) module to Zebra (now package "idzebra").
  * Add GRS-1 render for ZOOM using same format as yaz-client.
* Fri Nov 22 2002 ke@suse.de
- Update to version 1.9.1; changes since 1.8.8:
  * Add man pages: yaz-client(1), yaz-ztest(8), yaz(7), zoomsh(1).
  * Bugfixes: ESpec handling in data1 module; handle PDU encoding
    failures properly; ZOOM_record_get for type "database"; ZOOM C
    record cache so that preferredRecordSyntax and elementSetName is
    used to check for already fetched records.
  * SGML reader parses comments and makes them part of the data1 tree.
  * Add more Bib-1 diagnostics (approved extensions).
  * PQF parser rejects bad queries - including those with extra
    characters in them. PQF parser used to silently ignore that.
    Cleaner API for PQF added, which allows you to get detailed
    error information for bad queries (see yaz/pquery.h).
  * Use iconv.
  * Remov XML reader (d1_expat.c). It's part of Zebra instead.
* Mon Aug  5 2002 ke@suse.de
- Update to version 1.8.8:
  * Bug fixes.
  * Modify data1 to handle XML and character set encodings.
  * New COMSTACK type: local UNIX socket. It's useful if you have
    a local service and/or want extreme performance.
- Add expat and readline-devel to #neededforbuild to link against expat
  and readline.
* Mon May 27 2002 ke@suse.de
- Update to version 1.8.7:
  - Bug fixes.
  - Better i18n support (ZOOM API and YAZ client).
* Wed May  8 2002 ke@suse.de
- Use %%_libdir macro.
* Mon Apr  8 2002 ke@suse.de
- Update to version 1.8.6.
* Mon Mar 11 2002 ke@suse.de
- New package: version 1.8.5.
